#!/usr/bin/gnuplot

set term x11

nm = 1.e-9
h = 6.63e-34
k_B = 1.38e-23
R_S = 6.955e8
c = 2.99792458e8

B(T, lambda) = 2.*h*c/lambda**5 / (exp(h*c/(lambda*k_B*T)) - 1.)

Lum(T, R, lambda) = T > 0.0 ? pi*B(T, lambda) * 4.*pi*R**2 : 0.0

load "Lum.lab"

Lum1(lambda) = Lum(T1, R1*R_S, lambda)
Lum2(lambda) = Lum(T2, R2*R_S, lambda)
Lum3(lambda) = Lum(T3, R3*R_S, lambda)
Lum4(lambda) = Lum(T4, R4*R_S, lambda)

Lumtot(lambda) = Lum1(lambda)+Lum2(lambda)+Lum3(lambda)+Lum4(lambda)

set xl "lambda [nm]"
set yl "Lum []"

set xr [300:2800]
set yr [0:1.1]
ps = 1

p \
  Lum1(x*nm)/Lumtot(x*nm) lt 1 lw 2,\
  Lum2(x*nm)/Lumtot(x*nm) lt 2 lw 2,\
  Lum3(x*nm)/Lumtot(x*nm) lt 3 lw 2,\
  Lum4(x*nm)/Lumtot(x*nm) lt 4 lw 2,\
  Lumtot(x*nm)/Lumtot(x*nm),\
  "Vis.dat" u ($4/nm):(0),\
  "Lum.dat" u 1:2 t "Aa" w l lt 1,\
  "Lum.dat" u 1:3 t "Ab" w l lt 2,\
  "Lum.dat" u 1:4 t "B"  w l lt 3,\
  "<awk '/synthetic/' Lum.dat"      u 1:2 t "synthetic"      w p lt 1 pt 1 ps ps,\
  "<awk '/synthetic/' Lum.dat"      u 1:3 not                w p lt 2 pt 1 ps ps,\
  "<awk '/synthetic/' Lum.dat"      u 1:4 not                w p lt 3 pt 1 ps ps,\
  "<awk '/photometry/' Lum.dat"     u 1:2 t "photometry"     w p lt 1 pt 2 ps ps,\
  "<awk '/photometry/' Lum.dat"     u 1:3 not                w p lt 2 pt 2 ps ps,\
  "<awk '/photometry/' Lum.dat"     u 1:4 not                w p lt 3 pt 2 ps ps,\
  "<awk '/interferometry/' Lum.dat" u 1:2 t "interferometry" w p lt 1 pt 3 ps ps,\
  "<awk '/interferometry/' Lum.dat" u 1:3 not                w p lt 2 pt 3 ps ps,\
  "<awk '/interferometry/' Lum.dat" u 1:4 not                w p lt 3 pt 3 ps ps
  

pa -1

set term png small
set out "Lum.png"
rep

q


